==> apache-cxf-3.4.8-src.zip: apache-cxf-3.4.8-src/rt/rs/security/oauth-parent/oauth2/src/main/java/org/apache/cxf/rs/security/oauth2/client/AbstractAuthSupplier.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.rs.security.oauth2.client;

import org.apache.cxf.rs.security.oauth2.common.ClientAccessToken;

public abstract class AbstractAuthSupplier {
    private ClientAccessToken clientAccessToken = new ClientAccessToken();
    protected AbstractAuthSupplier(String type) {
        clientAccessToken = new ClientAccessToken();
        clientAccessToken.setTokenType(type);
    }
    public void setAccessToken(String accessToken) {
        clientAccessToken.setTokenKey(accessToken);
    }
    protected String createAuthorizationHeader() {
        return OAuthClientUtils.createAuthorizationHeader(getClientAccessToken());
    }
    protected ClientAccessToken getClientAccessToken() {
        return clientAccessToken;
    }
    protected void setClientAccessToken(ClientAccessToken clientAccessToken) {
        this.clientAccessToken = clientAccessToken;
    }

}

==> apache-cxf-3.5.11-src.zip: apache-cxf-3.5.11-src/rt/rs/security/oauth-parent/oauth2/src/main/java/org/apache/cxf/rs/security/oauth2/client/AbstractAuthSupplier.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.rs.security.oauth2.client;

import org.apache.cxf.rs.security.oauth2.common.ClientAccessToken;

public abstract class AbstractAuthSupplier {
    private ClientAccessToken clientAccessToken;
    protected AbstractAuthSupplier(String type) {
        clientAccessToken = new ClientAccessToken();
        clientAccessToken.setTokenType(type);
    }
    public void setAccessToken(String accessToken) {
        clientAccessToken.setTokenKey(accessToken);
    }
    protected String createAuthorizationHeader() {
        return OAuthClientUtils.createAuthorizationHeader(getClientAccessToken());
    }
    protected ClientAccessToken getClientAccessToken() {
        return clientAccessToken;
    }
    protected void setClientAccessToken(ClientAccessToken clientAccessToken) {
        this.clientAccessToken = clientAccessToken;
    }

}
